=head1

Locale::CLDR::Locales::Rof::Any::Tz - Package for language Rombo

=cut

package Locale::CLDR::Locales::Rof::Any::Tz;
# This file auto generated from Data\common\main\rof_TZ.xml
#	on Wed 10 Feb  8:20:55 am GMT

use version;

our $VERSION = version->declare('v0.28.3');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moose;

extends('Locale::CLDR::Locales::Rof::Any');
no Moose;
__PACKAGE__->meta->make_immutable;

1;

# vim: tabstop=4
